package hdl

import (
	"applet/app/admin/enum"
	"applet/app/admin/lib/validate"
	"applet/app/admin/md"
	"applet/app/admin/svc"
	svc2 "applet/app/admin/svc/enterprise_manage"
	"applet/app/db"
	"applet/app/db/model"
	"applet/app/e"
	enum2 "applet/app/enum"
	"applet/app/utils"
	"fmt"
	"github.com/360EntSecGroup-Skylar/excelize"
	"github.com/gin-gonic/gin"
	"github.com/jinzhu/copier"
	"strconv"
	"time"
)

func FactoryIdentityList(c *gin.Context) {
	enterpriseId := utils.StrToInt(c.DefaultQuery("enterprise_id", "0"))
	var req md.FactoryIdentityListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	factoryIdentity := db.FactoryIdentityDb{}
	factoryIdentity.Set(enterpriseId)
	factoryIdentityList, total, err := factoryIdentity.FindFactoryIdentity(req.Page, req.Limit)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	var result []*md.FactoryIdentityListResp
	for _, v := range *factoryIdentityList {
		var temp md.FactoryIdentityListResp
		copier.Copy(&temp, v)
		sql := fmt.Sprintf("SELECT count(*) as total FROM factory_identity_with_user_identity where factory_identity_id = %d", v.Id)
		mapArr1, err1 := db.QueryNativeString(db.Db, sql)
		if err1 != nil {
			e.OutErr(c, e.ERR, err1.Error())
			return
		}
		temp.WithUserIdentitiesNum = mapArr1[0]["total"]
		result = append(result, &temp)
	}

	e.OutSuc(c, map[string]interface{}{
		"list":  result,
		"total": total,
		"state": []map[string]interface{}{
			{
				"name":  enum.FactoryIdentityState(enum.FactoryIdentityStateForNormal).String(),
				"value": enum.FactoryIdentityStateForNormal,
			},
			{
				"name":  enum.FactoryIdentityState(enum.FactoryIdentityStateForFreeze).String(),
				"value": enum.FactoryIdentityStateForFreeze,
			},
		},
		"is_subsidy": []map[string]interface{}{
			{
				"name":  enum.FactoryIdentityIsSubsidy(enum.FactoryIdentityIsSubsidyForYes).String(),
				"value": enum.FactoryIdentityIsSubsidyForYes,
			},
			{
				"name":  enum.FactoryIdentityIsSubsidy(enum.FactoryIdentityIsSubsidyForNo).String(),
				"value": enum.FactoryIdentityIsSubsidyForNo,
			},
		},
		"is_limit_consume_num": []map[string]interface{}{
			{
				"name":  enum.FactoryIdentityIsLimitConsumeNum(enum.FactoryIdentityIsLimitConsumeNumForNo).String(),
				"value": enum.FactoryIdentityIsLimitConsumeNumForNo,
			},
			{
				"name":  enum.FactoryIdentityIsLimitConsumeNum(enum.FactoryIdentityIsLimitConsumeNumForYes).String(),
				"value": enum.FactoryIdentityIsLimitConsumeNumForYes,
			},
		},
	}, nil)
	return
}

func AddFactoryIdentity(c *gin.Context) {
	enterpriseId := utils.StrToInt(c.DefaultQuery("enterprise_id", "0"))
	var req md.AddFactoryIdentityReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	factoryIdentityDb := db.FactoryIdentityDb{}
	factoryIdentityDb.Set(0)
	now := time.Now()
	_, err = factoryIdentityDb.FactoryIdentityInsert(&model.FactoryIdentity{
		Name:              req.Name,
		EnterpriseId:      enterpriseId,
		State:             enum.FactoryIdentityStateForNormal,
		Memo:              req.Memo,
		IsSubsidy:         req.IsSubsidy,
		SubsidyAmount:     req.SubsidyAmount,
		LeastPayAmount:    req.LeastPayAmount,
		IsLimitConsumeNum: req.IsLimitConsumeNum,
		LimitConsumeNum:   req.LimitConsumeNum,
		CreateAt:          now.Format("2006-01-02 15:04:05"),
		UpdateAt:          now.Format("2006-01-02 15:04:05"),
	})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func UpdateFactoryIdentity(c *gin.Context) {
	var req md.UpdateFactoryIdentityReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	factoryIdentityDb := db.FactoryIdentityDb{}
	factoryIdentityDb.Set(0)
	factoryIdentity, err := factoryIdentityDb.GetFactoryIdentity(req.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if factoryIdentity == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到相应记录")
		return
	}
	factoryIdentity.Name = req.Name
	factoryIdentity.Memo = req.Memo
	factoryIdentity.IsSubsidy = req.IsSubsidy
	factoryIdentity.SubsidyAmount = req.SubsidyAmount
	factoryIdentity.LeastPayAmount = req.LeastPayAmount
	factoryIdentity.IsLimitConsumeNum = req.IsLimitConsumeNum
	factoryIdentity.LimitConsumeNum = req.LimitConsumeNum
	_, err = factoryIdentityDb.UpdateFactoryIdentity(factoryIdentity,
		"name", "memo", "is_subsidy", "subsidy_amount", "least_pay_amount", "is_limit_consume_num", "limit_consume_num")
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func UpdateFactoryIdentityState(c *gin.Context) {
	var req md.UpdateFactoryIdentityStateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	factoryIdentityDb := db.FactoryIdentityDb{}
	factoryIdentityDb.Set(0)
	factoryIdentity, err := factoryIdentityDb.GetFactoryIdentity(req.Id)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if factoryIdentity == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到相应记录")
		return
	}
	factoryIdentity.State = req.State
	_, err = factoryIdentityDb.UpdateFactoryIdentity(factoryIdentity, "state")
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func DeleteFactoryIdentity(c *gin.Context) {
	id := c.Param("id")
	factoryIdentityDb := db.FactoryIdentityDb{}
	factoryIdentityDb.Set(0)
	role, err := factoryIdentityDb.GetFactoryIdentity(utils.StrToInt(id))
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if role == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到相应记录")
		return
	}

	err = svc.DeleteFactoryIdentity(utils.StrToInt(id))
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func BindUserFactoryIdentity(c *gin.Context) {
	var req md.BindFactoryIdentityReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc.BindUserFactoryIdentity(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func SetBasicFactory(c *gin.Context) {
	enterpriseId := utils.StrToInt(c.DefaultQuery("enterprise_id", "0"))
	var req md.SetBasicFactoryReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	now := time.Now()

	//1、更新 factory_set
	factorySetDb := db.FactorySetDb{}
	factorySetDb.Set(enterpriseId)
	set, err := factorySetDb.GetFactorySet()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if set != nil {
		set.IsOpenNaturalCustomer = req.IsOpenNaturalCustomer
		set.NaturalCustomerServiceFee = req.NaturalCustomerServiceFee
		set.UpdateAt = now.Format("2006-01-02 15:04:05")
		_, err2 := factorySetDb.FactorySetUpdate(set,
			"is_open_natural_customer", "natural_customer_service_fee", "update_at")
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	} else {
		_, err2 := factorySetDb.FactorySetInsert(&model.FactorySet{
			EnterpriseId:              enterpriseId,
			IsOpenNaturalCustomer:     req.IsOpenNaturalCustomer,
			NaturalCustomerServiceFee: req.NaturalCustomerServiceFee,
			CreateAt:                  now.Format("2006-01-02 15:04:05"),
			UpdateAt:                  now.Format("2006-01-02 15:04:05"),
		})
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func GetBasicFactory(c *gin.Context) {
	enterpriseId := utils.StrToInt(c.DefaultQuery("enterprise_id", "0"))

	//1、获取 factory_set
	factorySetDb := db.FactorySetDb{}
	factorySetDb.Set(enterpriseId)
	set, err := factorySetDb.GetFactorySet()
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if set == nil {
		set = &model.FactorySet{
			EnterpriseId:              enterpriseId,
			IsOpenNaturalCustomer:     1,
			NaturalCustomerServiceFee: "0.00",
			CreateAt:                  time.Now().Format("2006-01-02 15:04:05"),
			UpdateAt:                  time.Now().Format("2006-01-02 15:04:05"),
		}
		_, err2 := factorySetDb.FactorySetInsert(set)
		if err2 != nil {
			e.OutErr(c, e.ERR_DB_ORM, err2.Error())
			return
		}
	}

	e.OutSuc(c, map[string]interface{}{
		"factory_set": set,
		"is_open_natural_customer": []map[string]interface{}{
			{
				"name":  enum.FactorySetIsOpenNaturalCustomer(enum.FactorySetIsOpenNaturalCustomerForYes).String(),
				"value": enum.FactorySetIsOpenNaturalCustomerForYes,
			},
			{
				"name":  enum.FactorySetIsOpenNaturalCustomer(enum.FactorySetIsOpenNaturalCustomerForNo).String(),
				"value": enum.FactorySetIsOpenNaturalCustomerForNo,
			},
		},
	}, nil)
	return
}

func FactoryDownloadTemplateExcel(c *gin.Context) {
	e.OutSuc(c, "/template/工厂(身份信息导入模板).xlsx", nil)
	return
}

func FactoryImportUserIdentity(c *gin.Context) {
	enterpriseIdStr := c.DefaultQuery("enterprise_id", "")
	enterpriseId := utils.StrToInt(enterpriseIdStr)
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(enterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	files, _ := c.FormFile("file")
	dst := "./static/upload/" + files.Filename
	err = c.SaveUploadedFile(files, dst)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	xlsx, err := excelize.OpenFile(dst)
	rows := xlsx.GetRows("Sheet" + "1")
	for key, row := range rows {
		if key > 0 && (row[0] != "" && row[1] != "" && row[2] != "" && row[3] != "") {
			var certType = 1
			if row[0] == "学工号" {
				certType = 2
			}
			idNo := row[1]
			name := row[2]

			//查找当前工厂身份是否存在
			factoryIdentityDb := db.FactoryIdentityDb{}
			factoryIdentityDb.Set(enterpriseId)
			factoryIdentity, err := factoryIdentityDb.GetFactoryIdentityByName(row[3])
			if err != nil {
				e.OutErr(c, e.ERR_DB_ORM, err.Error())
				return
			}
			if factoryIdentity == nil {
				continue
			}

			//查找当前用户身份是否已存在
			userIdentityDb := db.UserIdentityDb{}
			userIdentityDb.Set(0)

			isHasUserIdentity, err := userIdentityDb.UserIdentityExist(enterpriseId, idNo, certType)
			if err != nil {
				e.OutErr(c, e.ERR_DB_ORM, err.Error())
				return
			}
			if isHasUserIdentity != nil {
				continue
			}

			now := time.Now()
			//新增身份信息
			userIdentity := &model.UserIdentity{
				Uid:          0,
				Name:         name,
				IdNo:         idNo,
				CertType:     certType,
				Kind:         enum2.UserIdentityKindForCommon,
				Identity:     enum2.UserIdentityForFactory,
				EnterpriseId: enterpriseId,
				State:        enum2.UserIdentityStateForNormal,
				Memo:         "",
				CreateAt:     now.Format("2006-01-02 15:04:05"),
				UpdateAt:     now.Format("2006-01-02 15:04:05"),
			}
			insertAffected, err := userIdentityDb.UserIdentityInsert(userIdentity)
			if err != nil {
				e.OutErr(c, e.ERR_DB_ORM, err.Error())
				return
			}
			if insertAffected <= 0 {
				e.OutErr(c, e.ERR_DB_ORM, "新增身份数据失败")
				return
			}

			//更新 factory_identity
			factoryIdentityWithUserIdentityDb := db.FactoryIdentityWithUserIdentityDb{}
			factoryIdentityWithUserIdentityDb.Set()
			info, err := factoryIdentityWithUserIdentityDb.GetFactoryIdentityWithUserIdentity(insertAffected)
			if err != nil {
				e.OutErr(c, e.ERR_DB_ORM, err.Error())
				return
			}
			if info == nil {
				factoryIdentityWithUserIdentityDb.AddFactoryIdentityWithUserIdentity(&model.FactoryIdentityWithUserIdentity{
					UserIdentityId:    insertAffected,
					FactoryIdentityId: factoryIdentity.Id,
					CreateAt:          now.Format("2006-01-02 15:04:05"),
					UpdateAt:          now.Format("2006-01-02 15:04:05"),
				})
			} else {
				info.FactoryIdentityId = factoryIdentity.Id
				_, err1 := factoryIdentityWithUserIdentityDb.UpdateFactoryIdentityWithUserIdentity(info, "factory_identity_id")
				if err1 != nil {
					e.OutErr(c, e.ERR_DB_ORM, err1.Error())
					return
				}
			}
		}
	}

	e.OutSuc(c, "success", nil)
	return
}

func FactoryUserUpdate(c *gin.Context) {
	var req md.FactoryUserUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.FactoryUserUpdate(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func FactoryUserDelete(c *gin.Context) {
	var req md.FactoryUserDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.FactoryUserDelete(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func FactoryWorkerList(c *gin.Context) {
	var req md.FactoryWorkerListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	resp, total, err := svc2.FactoryWorkerList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"user_identity_cert_type_list": []map[string]interface{}{
			{
				"name":  enum2.UserIdentityCertType.String(enum2.UserIdentityCertTypeForIdCard),
				"value": enum2.UserIdentityCertTypeForIdCard,
			},
			{
				"name":  enum2.UserIdentityCertType.String(enum2.UserIdentityCertTypeForStudentId),
				"value": enum2.UserIdentityCertTypeForStudentId,
			},
			//{
			//	"name":  enum.UserIdentityCertType.String(enum.UserIdentityCertTypeForPassport),
			//	"value": enum.UserIdentityCertTypeForPassport,
			//},
		},
	}, nil)
	return
}

func FactoryWorkerUpdate(c *gin.Context) {
	var req md.FactoryWorkerUpdateReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	err = svc2.FactoryWorkerUpdate(req)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}

	e.OutSuc(c, "success", nil)
	return
}

func FactoryWorkerDelete(c *gin.Context) {
	var req md.FactoryWorkerDeleteReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	enterpriseDb := db.EnterpriseDb{}
	enterpriseDb.Set()
	enterprise, err := enterpriseDb.GetEnterprise(req.EnterpriseId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if enterprise == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}

	err = svc2.FactoryWorkerDelete(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func FactoryWorkerAdd(c *gin.Context) {
	var req md.FactoryWorkerAddReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	//1、查找当前身份是否已存在
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	isHasUserIdentity, err := userIdentityDb.UserIdentityExist(req.EnterpriseId, req.IdNo, req.CertType)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if isHasUserIdentity != nil {
		e.OutErr(c, e.ERR, "当前身份已存在,直接修改身份即可!")
		return
	}

	now := time.Now()
	//2、新增身份信息
	userIdentity := &model.UserIdentity{
		Uid:          0,
		Name:         req.Name,
		IdNo:         req.IdNo,
		CertType:     req.CertType,
		Kind:         enum2.UserIdentityKindForCommon,
		Identity:     enum2.UserIdentityForFactory,
		EnterpriseId: req.EnterpriseId,
		State:        enum2.UserIdentityStateForNormal,
		Memo:         "",
		CreateAt:     now.Format("2006-01-02 15:04:05"),
		UpdateAt:     now.Format("2006-01-02 15:04:05"),
	}
	insertAffected, err := userIdentityDb.UserIdentityInsert(userIdentity)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if insertAffected <= 0 {
		e.OutErr(c, e.ERR_DB_ORM, "新增身份数据失败")
		return
	}

	factoryIdentityWithUserIdentityDb := db.FactoryIdentityWithUserIdentityDb{}
	factoryIdentityWithUserIdentityDb.Set()
	_, err = factoryIdentityWithUserIdentityDb.AddFactoryIdentityWithUserIdentity(&model.FactoryIdentityWithUserIdentity{
		UserIdentityId:    userIdentity.Id,
		FactoryIdentityId: req.FactoryIdentityId,
		CreateAt:          now.Format("2006-01-02 15:04:05"),
		UpdateAt:          now.Format("2006-01-02 15:04:05"),
	})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, "关联工厂身份失败")
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

func FactoryOrdList(c *gin.Context) {
	var req md.FactoryOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	resp, total, err := svc2.FactoryOrdList(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, map[string]interface{}{
		"list":  resp,
		"total": total,
		"order_status_list": []map[string]interface{}{
			{
				"name":  enum2.FactoryOrdOrderStatus.String(enum2.FactoryOrdOrderStatusForSuccess),
				"value": enum2.FactoryOrdOrderStatusForSuccess,
			},
			{
				"name":  enum2.FactoryOrdOrderStatus.String(enum2.FactoryOrdOrderStatusForRefund),
				"value": enum2.FactoryOrdOrderStatusForRefund,
			},
			{
				"name":  enum2.FactoryOrdOrderStatus.String(enum2.FactoryOrdOrderStatusForClose),
				"value": enum2.FactoryOrdOrderStatusForClose,
			},
		},
		"trade_channel_list": []map[string]interface{}{
			{
				"name":  enum2.FactoryOrdTradeChannel.String(enum2.FactoryOrdTradeChannelForAli),
				"value": enum2.FactoryOrdTradeChannelForAli,
			},
			{
				"name":  enum2.FactoryOrdTradeChannel.String(enum2.FactoryOrdTradeChannelForWx),
				"value": enum2.FactoryOrdTradeChannelForWx,
			},
		},
	}, nil)
	return
}

func FactoryOrdListExport(c *gin.Context) {
	var req md.FactoryOrdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}

	resp, err := svc2.FactoryOrdListExport(req)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}

	titleList := []string{"校企名称", "用户电话", "就餐人姓名", "订单号", "交易号", "支付状态", "支付时间", "消费档口", "订单总金额", "实收金额", "买家支付金额", "补贴金额", "服务费用", "交易渠道"}
	xlsx := excelize.NewFile()
	xlsx.SetSheetRow("Sheet1", "A1", &titleList)
	style, err := xlsx.NewStyle(`{"fill":{"type":"pattern","color":["FFFF00"],"pattern":1}, "alignment":{"horizontal":"center"}}`)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	xlsx.SetCellStyle("Sheet1", "A1", "N1", style)
	xlsx.SetColWidth("Sheet1", "A", "N", 25)
	//xlsx.SetColWidth("Sheet1", "B", "B", 30)
	//xlsx.SetColWidth("Sheet1", "C", "E", 15)
	//xlsx.SetColWidth("Sheet1", "F", "I", 10)
	//xlsx.SetColWidth("Sheet1", "J", "J", 20)
	//xlsx.SetColWidth("Sheet1", "K", "K", 10)
	//xlsx.SetColWidth("Sheet1", "L", "L", 25)
	//xlsx.SetColWidth("Sheet1", "M", "M", 15)
	//表头被第一行用了，只能从第二行开始
	j := 2
	//var totalAmount = 0.00
	for _, v := range resp {
		xlsx.SetSheetRow("Sheet1", "A"+strconv.Itoa(j), &[]interface{}{v.EnterpriseName, v.Phone, v.UserIdentityName, v.OutTradeNo, v.TradeNo, enum2.FactoryOrdOrderStatus.String(enum2.FactoryOrdOrderStatus(v.OrderStatus)),
			v.GmtPayment, v.ShopName, v.TotalAmount, v.ReceiptAmount, v.BuyerPayAmount, v.SubsidyAmount, v.ServiceFee, v.TradeChannel})
		j++
	}

	//xlsx.SetSheetRow("Sheet1", "A"+strconv.Itoa(j), &[]interface{}{"总计：", "-", "-", "-", "-", "-", "-", totalAmount, "-", "-", "-", "-", "-"})

	c.Header("Content-Type", "application/octet-stream")
	c.Header("Content-Disposition", "attachment; filename="+"工厂消费记录"+".xlsx")
	c.Header("Content-Transfer-Encoding", "binary")
	//回写到web 流媒体 形成下载
	_ = xlsx.Write(c.Writer)
	return
}
