package md

type FactoryIdentityListResp struct {
	Id                    int    `json:"id" xorm:"not null pk autoincr INT(11)"`
	Name                  string `json:"name" xorm:"not null default '' comment('名称') VARCHAR(255)"`
	State                 int    `json:"state" xorm:"not null default 1 comment('状态(1:正常 2:冻结)') TINYINT(1)"`
	Memo                  string `json:"memo" xorm:"not null default '' comment('备注') VARCHAR(255)"`
	IsSubsidy             int    `json:"is_subsidy" xorm:"not null default 0 comment('是否优惠补贴(0:否 1:是)') TINYINT(1)"`
	SubsidyAmount         string `json:"subsidy_amount" xorm:"not null default 0.00 comment('补贴金额') DECIMAL(8,2)"`
	LeastPayAmount        string `json:"least_pay_amount" xorm:"not null default 0.00 comment('最少支付金额') DECIMAL(8,2)"`
	IsLimitConsumeNum     int    `json:"is_limit_consume_num" xorm:"not null default 0 comment('是否限制消费次数') TINYINT(1)"`
	LimitConsumeNum       int    `json:"limit_consume_num" xorm:"default 0 comment('限制消费次数/日') TINYINT(1)"`
	WithUserIdentitiesNum string `json:"with_user_identities_num"`
	CreateAt              string `json:"create_at" xorm:"not null default 'CURRENT_TIMESTAMP' DATETIME"`
	UpdateAt              string `json:"update_at" xorm:"not null default 'CURRENT_TIMESTAMP' DATETIME"`
}

type UpdateFactoryIdentityStateReq struct {
	Id    int `json:"id" binding:"required" label:"id"`
	State int `json:"state" binding:"required" label:"状态"`
}

type AddFactoryIdentityReq struct {
	Name              string `json:"name" binding:"required" label:"名称"`
	Memo              string `json:"memo" label:"备注"`
	IsSubsidy         int    `json:"is_subsidy" label:"是否优惠补贴(0:否 1:是)"`
	SubsidyAmount     string `json:"subsidy_amount" label:"补贴金额"`
	LeastPayAmount    string `json:"least_pay_amount" label:"最少支付金额"`
	IsLimitConsumeNum int    `json:"is_limit_consume_num" label:"是否限制消费次数"`
	LimitConsumeNum   int    `json:"limit_consume_num" label:"限制消费次数/日"`
}

type UpdateFactoryIdentityReq struct {
	Id                int    `json:"id" binding:"required" label:"id"`
	Name              string `json:"name" binding:"required" label:"名称"`
	Memo              string `json:"memo" label:"备注"`
	IsSubsidy         int    `json:"is_subsidy" label:"是否优惠补贴(0:否 1:是)"`
	SubsidyAmount     string `json:"subsidy_amount" label:"补贴金额"`
	LeastPayAmount    string `json:"least_pay_amount" label:"最少支付金额"`
	IsLimitConsumeNum int    `json:"is_limit_consume_num" label:"是否限制消费次数"`
	LimitConsumeNum   int    `json:"limit_consume_num" label:"限制消费次数/日"`
}

type FactoryIdentityListReq struct {
	Limit     int    `json:"limit"`
	Page      int    `json:"page" `
	Name      string `json:"name"`
	State     int    `json:"state"`
	StartDate string `json:"start_date" `
	EndDate   string `json:"end_date" `
}

type BindFactoryIdentityReq struct {
	UserIdentitiesId  int `json:"user_identities_id" binding:"required"`
	FactoryIdentityId int `json:"factory_identity_id" label:"角色id"`
}

type SetBasicFactoryReq struct {
	IsOpenNaturalCustomer     int    `json:"is_open_natural_customer" binding:"required"`
	NaturalCustomerServiceFee string `json:"natural_customer_service_fee" binding:"required"`
}

type FactoryWorkerListReq struct {
	EnterpriseId int    `json:"enterprise_id" binding:"required" label:"企业id"`
	Limit        int    `json:"limit" binding:"required"`
	Page         int    `json:"page" binding:"required"`
	Name         string `json:"name" label:"姓名"`
	IdNo         string `json:"id_no" label:"身份证号"`
	Phone        string `json:"phone" label:"手机号"`
}

type FactoryWorkerListResp struct {
	UserIdentityId    int    `json:"user_identity_id" label:"用户身份id"`
	IdNo              string `json:"id_no" label:"身份证号"`
	CertType          int    `json:"cert_type" label:"证件类型"`
	Phone             string `json:"parent_phone" label:"电话"`
	Name              string `json:"name" label:"姓名"`
	FactoryIdentityId int    `json:"factory_identity_id" label:"工厂身份id"`
	FactoryIdentity   string `json:"factory_identity" label:"工厂身份"`
	CreateAt          string `json:"create_at" xorm:"not null default 'CURRENT_TIMESTAMP' DATETIME"`
	UpdateAt          string `json:"update_at" xorm:"not null default 'CURRENT_TIMESTAMP' DATETIME"`
}

type FactoryUserDeleteReq struct {
	EnterpriseId int   `json:"enterprise_id" binding:"required" label:"企业id"`
	Uids         []int `json:"uids" binding:"required" label:"用户id"`
}

type FactoryUserUpdateReq struct {
	EnterpriseId       int    `json:"enterprise_id" binding:"required" label:"企业id"`
	Uid                int    `json:"uid" binding:"required" label:"用户id"`
	Nickname           string `json:"nickname" binding:"required" label:"支付宝昵称"`
	Phone              string `json:"phone" binding:"required" label:"手机号"`
	BindUserIdentities []struct {
		UserIdentityId int    `json:"user_identity_id" label:"用户身份id"`
		IdNo           string `json:"id_no" label:"身份证号"`
		CertType       int    `json:"cert_type" label:"证件类型"`
		Name           string `json:"name" label:"姓名"`
	} `json:"user_identities" label:"身份列表"`
}

type FactoryWorkerUpdateReq struct {
	EnterpriseId      int    `json:"enterprise_id" binding:"required" label:"企业id"`
	UserIdentityId    int    `json:"user_identity_id" binding:"required" label:"用户身份id"`
	IdNo              string `json:"id_no" label:"身份证号"`
	CertType          int    `json:"cert_type" label:"证件类型(1:身份证 2:学工号 3:护照)"`
	Name              string `json:"name" label:"姓名"`
	FactoryIdentityId int    `json:"factory_identity_id" label:"工厂身份id"`
}

type FactoryWorkerDeleteReq struct {
	EnterpriseId    int   `json:"enterprise_id" binding:"required" label:"企业id"`
	UserIdentityIds []int `json:"user_identity_ids" binding:"required" label:"用户身份id"`
}

type FactoryWorkerAddReq struct {
	EnterpriseId      int    `json:"enterprise_id" binding:"required" label:"企业id"`
	Name              string `json:"name" label:"名称"`
	CertType          int    `json:"cert_type" label:"证件类型(1:身份证 2:学工号 3:护照)"`
	IdNo              string `json:"id_no" label:"身份证号"`
	FactoryIdentityId int    `json:"factory_identity_id" label:"工厂身份id"`
}

type FactoryOrdListReq struct {
	EnterpriseId int    `json:"enterprise_id" label:"企业id"`
	Limit        int    `json:"limit" binding:"required"`
	Page         int    `json:"page" binding:"required"`
	Name         string `json:"name" label:"姓名"`
	Phone        string `json:"phone" label:"用户电话"`
	OutTradeNo   string `json:"out_trade_no" label:"订单号"`
	TradeNo      string `json:"trade_no" label:"交易单号"`
	OrderStatus  int    `json:"order_status" label:"订单状态"`
	StartDate    string `json:"start_date" label:"订单-开始时间"`
	EndDate      string `json:"end_date" label:"订单-截止时间"`
	TerminalId   string `json:"terminal_id" label:"设备编号"`
	TradeChannel string `json:"trade_channel" label:"交易渠道"`
	ShopName     string `json:"shop_name" label:"消费档口"`
}

type FactoryOrdListResp struct {
	EnterpriseId     int    `json:"enterprise_id" `
	EnterpriseName   string `json:"enterprise_name" `
	Uid              int    `json:"uid" `
	UserIdentityId   int    `json:"user_identity_id" `
	UserIdentityName string `json:"user_identity_name" `
	OutTradeNo       string `json:"out_trade_no" `
	TradeNo          string `json:"trade_no"`
	OrderStatus      int    `json:"order_status"`
	Phone            string `json:"phone"`
	GmtPayment       string `json:"gmt_payment"`
	TerminalId       string `json:"terminal_id" label:"设备编号"`
	ShopName         string `json:"shop_name" label:"消费档口"`
	TotalAmount      string `json:"total_amount" label:"订单总金额"`
	ReceiptAmount    string `json:"receipt_amount" label:"实收金额"`
	BuyerPayAmount   string `json:"buyer_pay_amount" label:"买家支付金额"`
	SubsidyAmount    string `json:"subsidy_amount" label:"补贴金额"`
	ServiceFee       string `json:"service_fee" label:"服务费用"`
	TradeChannel     string `json:"trade_channel" label:"交易渠道"`
}
