package svc

import (
	"applet/app/admin/md"
	"applet/app/db"
	"applet/app/db/model"
	enum2 "applet/app/enum"
	"applet/app/utils"
	"errors"
	"time"
)

func FactoryUserUpdate(req md.FactoryUserUpdateReq) (err error) {
	var userIdentities []model.UserIdentity
	err = db.Db.Where("uid =? AND enterprise_id =?", req.Uid, req.EnterpriseId).Find(&userIdentities)
	if err != nil {
		return
	}
	var userIdentityIds []int
	for _, v := range userIdentities {
		userIdentityIds = append(userIdentityIds, v.Id)
	}

	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()

	//2、新增 / 编辑 数据
	now := time.Now()

	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(req.Uid)

	var newUserIdentityIds []string
	for _, v := range req.BindUserIdentities {
		if v.UserIdentityId == 0 {
			// 新增
			insertId, err1 := userIdentityDb.UserIdentityInsertBySession(session, &model.UserIdentity{
				Uid:          req.Uid,
				Name:         v.Name,
				IdNo:         v.IdNo,
				CertType:     v.CertType,
				Kind:         enum2.UserIdentityKindForCommon,
				Identity:     enum2.UserIdentityForFactory,
				EnterpriseId: req.EnterpriseId,
				Memo:         "",
				State:        enum2.UserIdentityStateForNormal,
				CreateAt:     now.Format("2006-01-02 15:04:05"),
				UpdateAt:     now.Format("2006-01-02 15:04:05"),
			})
			if err1 != nil {
				_ = session.Rollback()
				return err1
			}

			newUserIdentityIds = append(newUserIdentityIds, utils.IntToStr(insertId))
		} else {
			//编辑
			identity, err2 := userIdentityDb.GetUserIdentity(v.UserIdentityId)
			if err != nil {
				_ = session.Rollback()
				return err2
			}
			if identity == nil {
				_ = session.Rollback()
				return errors.New("未查询到对应的身份信息记录")
			}
			identity.IdNo = v.IdNo
			identity.CertType = v.CertType
			identity.Name = v.Name
			identity.Identity = enum2.UserIdentityForFactory

			_, err3 := userIdentityDb.UserIdentityUpdateBySession(session, v.UserIdentityId, identity, "id_no", "cert_type", "name", "identity")
			if err3 != nil {
				_ = session.Rollback()
				return err3
			}

			newUserIdentityIds = append(newUserIdentityIds, utils.IntToStr(v.UserIdentityId))
		}
	}

	//3、删除需要删除的身份信息
	for _, v := range userIdentityIds {
		if !utils.InArr(utils.IntToStr(v), newUserIdentityIds) {
			_, err = session.Where("id = ?", v).Delete(model.UserIdentity{})
			if err != nil {
				_ = session.Rollback()
				return
			}

			_, err = session.Where("user_identity_id = ?", v).Delete(model.SelfSupportForUserFaceInfo{})
			if err != nil {
				_ = session.Rollback()
				return
			}
		}
	}
	return session.Commit()
}

func FactoryUserDelete(req md.FactoryUserDeleteReq) (err error) {
	//1、删除 user_identity
	var userIdentities []model.UserIdentity
	err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("uid", req.Uids).Find(&userIdentities)
	if err != nil {
		return
	}
	var userIdentityIds []int
	for _, v := range userIdentities {
		userIdentityIds = append(userIdentityIds, v.Id)
	}

	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("uid", req.Uids).Delete(model.UserIdentity{})
	if err != nil {
		return
	}

	//2、删除 factory_identity_with_user_identity
	_, err = db.Db.In("user_identity_id", userIdentityIds).Delete(model.FactoryIdentityWithUserIdentity{})
	if err != nil {
		return
	}

	return
}

func FactoryWorkerList(req md.FactoryWorkerListReq) (resp []md.FactoryWorkerListResp, count int64, err error) {

	sess := db.Db.Where("user_identity.enterprise_id =?", req.EnterpriseId).
		And("user_identity.identity =?", enum2.UserIdentityForFactory)
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.IdNo != "" {
		sess.And("user_identity.id_no like ?", "%"+req.IdNo+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}

	var m []*db.UserIdentityWithFactoryIdentity
	count, err = sess.
		Join("LEFT", "user", "user_identity.uid = user.id").
		Join("LEFT", "factory_identity_with_user_identity", "user_identity.id = factory_identity_with_user_identity.user_identity_id").
		Join("LEFT", "factory_identity", "factory_identity_with_user_identity.factory_identity_id = factory_identity.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	for _, v := range m {
		resp = append(resp, md.FactoryWorkerListResp{
			UserIdentityId:    v.UserIdentity.Id,
			IdNo:              v.UserIdentity.IdNo,
			CertType:          v.UserIdentity.CertType,
			Phone:             v.User.Phone,
			Name:              v.UserIdentity.Name,
			FactoryIdentityId: v.FactoryIdentity.Id,
			FactoryIdentity:   v.FactoryIdentity.Name,
			CreateAt:          v.FactoryIdentity.CreateAt,
			UpdateAt:          v.FactoryIdentity.UpdateAt,
		})
	}
	return
}

func FactoryWorkerUpdate(req md.FactoryWorkerUpdateReq) (err error) {
	//1、修改 `user_identity`
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	userIdentity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
	if err != nil {
		return
	}
	if userIdentity == nil {
		return errors.New("未查询到对应记录")
	}
	userIdentity.IdNo = req.IdNo
	userIdentity.CertType = req.CertType
	userIdentity.Name = req.Name
	_, err = userIdentityDb.UserIdentityUpdate(req.UserIdentityId, userIdentity, "id_no", "name", "cert_type")
	if err != nil {
		return
	}

	//2、更新 factory_identity_with_user_identity
	factoryIdentityWithUserIdentityDb := db.FactoryIdentityWithUserIdentityDb{}
	factoryIdentityWithUserIdentityDb.Set()
	info, err := factoryIdentityWithUserIdentityDb.GetFactoryIdentityWithUserIdentity(req.UserIdentityId)
	if err != nil {
		return
	}
	if info != nil {
		info.FactoryIdentityId = req.FactoryIdentityId
		_, err = factoryIdentityWithUserIdentityDb.UpdateFactoryIdentityWithUserIdentity(info, "factory_identity_id")
		if err != nil {
			return
		}
	} else {
		_, err = factoryIdentityWithUserIdentityDb.AddFactoryIdentityWithUserIdentity(&model.FactoryIdentityWithUserIdentity{
			UserIdentityId:    userIdentity.Id,
			FactoryIdentityId: req.FactoryIdentityId,
			CreateAt:          time.Now().Format("2006-01-02 15:04:05"),
			UpdateAt:          time.Now().Format("2006-01-02 15:04:05"),
		})
		if err != nil {
			return
		}
	}
	return
}

func FactoryWorkerDelete(req md.FactoryWorkerDeleteReq) (err error) {
	//1、删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("id", req.UserIdentityIds).Delete(model.UserIdentity{})
	if err != nil {
		return
	}

	//2、删除 factory_identity_with_user_identity
	_, err = db.Db.In("user_identity_id", req.UserIdentityIds).Delete(model.FactoryIdentityWithUserIdentity{})
	if err != nil {
		return
	}
	return
}

func FactoryOrdList(req md.FactoryOrdListReq) (resp []md.FactoryOrdListResp, count int64, err error) {
	sess := db.Db.Desc("factory_ord.id")
	if req.EnterpriseId != 0 {
		sess.And("factory_ord.enterprise_id =?", req.EnterpriseId)
	}
	if req.StartDate != "" {
		sess.And("factory_ord.gmt_payment >= ?", req.StartDate)
	}
	if req.EndDate != "" {
		sess.And("factory_ord.gmt_payment <= ?", req.EndDate)
	}
	if req.OrderStatus != 0 {
		sess.And("factory_ord.order_status = ?", req.OrderStatus)
	}
	if req.OutTradeNo != "" {
		sess.And("factory_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
	}
	if req.TerminalId != "" {
		sess.And("factory_ord.terminal_id like ?", "%"+req.TerminalId+"%")
	}
	if req.TradeNo != "" {
		sess.And("factory_ord.trade_no like ?", "%"+req.TradeNo+"%")
	}
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}
	if req.ShopName != "" {
		sess.And("factory_device.name like ?", "%"+req.ShopName+"%")
	}

	var m []*db.FactoryOrdWithUserIdentity
	count, err = sess.
		Join("LEFT", "user_identity", "factory_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "factory_device", "factory_ord.terminal_id = factory_device.terminal_id").
		Limit(req.Limit, (req.Page-1)*req.Limit).Desc("factory_ord.create_at").FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	for _, v := range m {
		resp = append(resp, md.FactoryOrdListResp{
			EnterpriseId:     v.Enterprise.Id,
			EnterpriseName:   v.Enterprise.Name,
			Uid:              v.User.Id,
			UserIdentityId:   v.UserIdentity.Id,
			UserIdentityName: v.UserIdentity.Name,
			OutTradeNo:       v.FactoryOrd.OutOrderNo,
			TradeNo:          v.FactoryOrd.TradeNo,
			OrderStatus:      v.FactoryOrd.OrderStatus,
			Phone:            v.User.Phone,
			GmtPayment:       v.FactoryOrd.GmtPayment,
			TerminalId:       v.FactoryOrd.TerminalId,
			ShopName:         v.FactoryDevice.Name,
			TotalAmount:      v.FactoryOrd.TotalAmount,
			ReceiptAmount:    v.FactoryOrd.ReceiptAmount,
			BuyerPayAmount:   v.FactoryOrd.BuyerPayAmount,
			SubsidyAmount:    v.FactoryOrd.SubsidyAmount,
			ServiceFee:       v.FactoryOrd.ServiceFee,
			TradeChannel:     v.FactoryOrd.TradeChannel,
		})
	}
	return
}

func FactoryOrdListExport(req md.FactoryOrdListReq) (resp []md.FactoryOrdListResp, err error) {
	sess := db.Db.Desc("factory_ord.id")
	if req.EnterpriseId != 0 {
		sess.And("factory_ord.enterprise_id =?", req.EnterpriseId)
	}
	if req.StartDate != "" {
		sess.And("factory_ord.gmt_payment >= ?", req.StartDate)
	}
	if req.EndDate != "" {
		sess.And("factory_ord.gmt_payment <= ?", req.EndDate)
	}
	if req.OrderStatus != 0 {
		sess.And("factory_ord.order_status = ?", req.OrderStatus)
	}
	if req.OutTradeNo != "" {
		sess.And("factory_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
	}
	if req.TerminalId != "" {
		sess.And("factory_ord.terminal_id like ?", "%"+req.TerminalId+"%")
	}
	if req.TradeNo != "" {
		sess.And("factory_ord.trade_no like ?", "%"+req.TradeNo+"%")
	}
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}
	if req.ShopName != "" {
		sess.And("factory_device.name like ?", "%"+req.ShopName+"%")
	}

	var m []*db.FactoryOrdWithUserIdentity
	err = sess.
		Join("LEFT", "user_identity", "factory_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "factory_device", "factory_ord.terminal_id = factory_device.terminal_id").
		Desc("factory_ord.create_at").Find(&m)
	if err != nil {
		return nil, err
	}
	if err != nil {
		return nil, err
	}

	for _, v := range m {
		resp = append(resp, md.FactoryOrdListResp{
			EnterpriseId:     v.Enterprise.Id,
			EnterpriseName:   v.Enterprise.Name,
			Uid:              v.User.Id,
			UserIdentityId:   v.UserIdentity.Id,
			UserIdentityName: v.UserIdentity.Name,
			OutTradeNo:       v.FactoryOrd.OutOrderNo,
			TradeNo:          v.FactoryOrd.TradeNo,
			OrderStatus:      v.FactoryOrd.OrderStatus,
			Phone:            v.User.Phone,
			GmtPayment:       v.FactoryOrd.GmtPayment,
			TerminalId:       v.FactoryOrd.TerminalId,
			ShopName:         v.FactoryDevice.Name,
			TotalAmount:      v.FactoryOrd.TotalAmount,
			ReceiptAmount:    v.FactoryOrd.ReceiptAmount,
			BuyerPayAmount:   v.FactoryOrd.BuyerPayAmount,
			SubsidyAmount:    v.FactoryOrd.SubsidyAmount,
			ServiceFee:       v.FactoryOrd.ServiceFee,
			TradeChannel:     v.FactoryOrd.TradeChannel,
		})
	}
	return
}
