package svc

import (
	"applet/app/admin/md"
	md2 "applet/app/customer/md"
	"applet/app/db"
	"applet/app/db/model"
	"applet/app/enum"
	"applet/app/utils"
	"time"
)

func CalcBySchoolTerm(uid int, isTeacher bool, buyPackageReq md2.BuyPackageReq) (totalPrice float64, data []*model.CentralKitchenForSchoolUserWithDay, err error) {
	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	cfg, err := sysCfgDb.SysCfgGetOne(enum.CentralKitchenForSchoolReserveMealTime)
	if err != nil {
		return
	}

	//1、查询出套餐基础设置
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(buyPackageReq.EnterpriseId)
	centralKitchenForSchoolWithSpecData, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		return
	}
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	classWithUserInfo, err := classWithUserDb.GetInfoByUserIdentityId(buyPackageReq.UserIdentityId)
	if err != nil {
		return
	}

	//2、查询出当前合适的package
	var m []model.CentralKitchenForSchoolPackage
	now := time.Now()
	today, _ := time.ParseInLocation("2006-01-02", time.Now().Format("2006-01-02"), time.Local)
	tomorrowDay := today.AddDate(0, 0, 1)

	err = db.Db.Where("enterprise_id =?", buyPackageReq.EnterpriseId).In("id", buyPackageReq.PackageIds).And("is_delete = 0").And("state = 1").Desc("end_date").Find(&m)
	if err != nil {
		return
	}
	centralKitchenForSchoolReserveMealTime, _ := time.ParseInLocation("2006-01-02 15:04:05", now.Format("2006-01-02")+" "+cfg.Val+":00", time.Local)

	//3、循环拼接数据
	for _, v := range m {
		centralKitchenForSchoolPackageWithDayDb := db.CentralKitchenForSchoolPackageWithDayDb{}
		centralKitchenForSchoolPackageWithDayDb.Set(v.Id)
		centralKitchenForSchoolPackageWithDay, err1 := centralKitchenForSchoolPackageWithDayDb.FindCentralKitchenForSchoolPackageWithDay()
		if err1 != nil {
			return
		}
		for _, v1 := range *centralKitchenForSchoolPackageWithDay {
			//3.1、判断是否小于今天
			date, _ := time.ParseInLocation("2006-01-02", v1.Date, time.Local)
			if today.After(date) || today.Equal(date) {
				continue
			}

			if tomorrowDay.Equal(date) {
				//2.2、判断是否过了明日可订餐时间
				if now.After(centralKitchenForSchoolReserveMealTime) {
					continue
				}
			}

			//3.3、计算价格 && 组装数据
			if v1.IsOpenBreakfast == md.OpenBreakfast && buyPackageReq.IsBuyBreakfast == 1 {
				//早餐
				var amount string
				if isTeacher {
					amount = centralKitchenForSchoolWithSpecData.BreakfastUnitPriceForTeacher
				} else {
					amount = classWithUserInfo.Period.BreakfastUnitPrice
				}
				totalPrice += utils.StrToFloat64(amount)
				data = append(data, &model.CentralKitchenForSchoolUserWithDay{
					Uid:          uid,
					EnterpriseId: buyPackageReq.EnterpriseId,
					IdentityId:   buyPackageReq.UserIdentityId,
					Amount:       amount,
					Kind:         enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
					Date:         v1.Date,
					State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
				})
			}

			if v1.IsOpenLunch == md.OpenLunch && buyPackageReq.IsBuyLunch == 1 {
				var amount string
				if isTeacher {
					amount = centralKitchenForSchoolWithSpecData.LunchUnitPriceForTeacher
				} else {
					amount = classWithUserInfo.Period.LunchUnitPrice
				}
				totalPrice += utils.StrToFloat64(amount)

				data = append(data, &model.CentralKitchenForSchoolUserWithDay{
					Uid:          uid,
					EnterpriseId: buyPackageReq.EnterpriseId,
					IdentityId:   buyPackageReq.UserIdentityId,
					Amount:       amount,
					Kind:         enum.CentralKitchenForSchoolUserWithDayKindForLunch,
					Date:         v1.Date,
					State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
				})
			}

			if v1.IsOpenDinner == md.OpenDinner && buyPackageReq.IsBuyDinner == 1 {
				var amount string
				if isTeacher {
					amount = centralKitchenForSchoolWithSpecData.DinnerUnitPriceForTeacher
				} else {
					amount = classWithUserInfo.Period.DinnerUnitPrice
				}
				totalPrice += utils.StrToFloat64(amount)
				data = append(data, &model.CentralKitchenForSchoolUserWithDay{
					Uid:          uid,
					EnterpriseId: buyPackageReq.EnterpriseId,
					IdentityId:   buyPackageReq.UserIdentityId,
					Kind:         enum.CentralKitchenForSchoolUserWithDayKindForDinner,
					Date:         v1.Date,
					Amount:       amount,
					State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
				})
			}
		}

	}
	return
}

func CalcByMonth(uid int, isTeacher bool, buyPackageReq md2.BuyPackageReq) (totalPrice float64, data []*model.CentralKitchenForSchoolUserWithDay, err error) {
	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	cfg, err := sysCfgDb.SysCfgGetOne(enum.CentralKitchenForSchoolReserveMealTime)
	if err != nil {
		return
	}

	//1、查询出套餐基础设置
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(buyPackageReq.EnterpriseId)
	centralKitchenForSchoolWithSpecData, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		return
	}
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	classWithUserInfo, err := classWithUserDb.GetInfoByUserIdentityId(buyPackageReq.UserIdentityId)
	if err != nil {
		return
	}

	//2、查询出当前合适的package
	var m []model.CentralKitchenForSchoolPackage
	now := time.Now()
	today, _ := time.ParseInLocation("2006-01-02", time.Now().Format("2006-01-02"), time.Local)
	tomorrowDay := today.AddDate(0, 0, 1)

	err = db.Db.Where("enterprise_id =?", buyPackageReq.EnterpriseId).And("id =?", buyPackageReq.PackageId).And("is_delete = 0").And("state = 1").Find(&m)
	if err != nil {
		return
	}
	centralKitchenForSchoolReserveMealTime, _ := time.ParseInLocation("2006-01-02 15:04:05", now.Format("2006-01-02")+" "+cfg.Val+":00", time.Local)

	//3、循环拼接数据
	for _, v := range m {
		centralKitchenForSchoolPackageWithDayDb := db.CentralKitchenForSchoolPackageWithDayDb{}
		centralKitchenForSchoolPackageWithDayDb.Set(v.Id)
		centralKitchenForSchoolPackageWithDay, err1 := centralKitchenForSchoolPackageWithDayDb.FindCentralKitchenForSchoolPackageWithDay()
		if err1 != nil {
			return
		}
		for _, v1 := range *centralKitchenForSchoolPackageWithDay {
			//3.1、判断是否小于今天
			date, _ := time.ParseInLocation("2006-01-02", v1.Date, time.Local)
			if today.After(date) || today.Equal(date) {
				continue
			}

			if tomorrowDay.Equal(date) {
				//2.2、判断是否过了今日可订餐时间
				if now.After(centralKitchenForSchoolReserveMealTime) {
					continue
				}
			}

			//3.3、计算价格 && 组装数据
			if v1.IsOpenBreakfast == md.OpenBreakfast && buyPackageReq.IsBuyBreakfast == 1 {
				//早餐
				var amount string
				if isTeacher {
					amount = centralKitchenForSchoolWithSpecData.BreakfastUnitPriceForTeacher
				} else {
					amount = classWithUserInfo.Period.BreakfastUnitPrice
				}

				totalPrice += utils.StrToFloat64(amount)
				data = append(data, &model.CentralKitchenForSchoolUserWithDay{
					Uid:          uid,
					EnterpriseId: buyPackageReq.EnterpriseId,
					IdentityId:   buyPackageReq.UserIdentityId,
					Amount:       amount,
					Kind:         enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
					Date:         v1.Date,
					State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
				})
			}

			if v1.IsOpenLunch == md.OpenLunch && buyPackageReq.IsBuyLunch == 1 {
				var amount string
				if isTeacher {
					amount = centralKitchenForSchoolWithSpecData.LunchUnitPriceForTeacher
				} else {
					amount = classWithUserInfo.Period.LunchUnitPrice
				}
				totalPrice += utils.StrToFloat64(amount)

				data = append(data, &model.CentralKitchenForSchoolUserWithDay{
					Uid:          uid,
					EnterpriseId: buyPackageReq.EnterpriseId,
					IdentityId:   buyPackageReq.UserIdentityId,
					Amount:       amount,
					Kind:         enum.CentralKitchenForSchoolUserWithDayKindForLunch,
					Date:         v1.Date,
					State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
				})
			}

			if v1.IsOpenDinner == md.OpenDinner && buyPackageReq.IsBuyDinner == 1 {
				var amount string
				if isTeacher {
					amount = centralKitchenForSchoolWithSpecData.DinnerUnitPriceForTeacher
				} else {
					amount = classWithUserInfo.Period.DinnerUnitPrice
				}
				totalPrice += utils.StrToFloat64(amount)
				data = append(data, &model.CentralKitchenForSchoolUserWithDay{
					Uid:          uid,
					EnterpriseId: buyPackageReq.EnterpriseId,
					IdentityId:   buyPackageReq.UserIdentityId,
					Kind:         enum.CentralKitchenForSchoolUserWithDayKindForDinner,
					Amount:       amount,
					Date:         v1.Date,
					State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
				})
			}
		}
	}
	return
}

func CalcByDay(uid int, isTeacher bool, buyPackageReq md2.BuyPackageReq) (totalPrice float64, data []*model.CentralKitchenForSchoolUserWithDay, err error) {
	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	cfg, err := sysCfgDb.SysCfgGetOne(enum.CentralKitchenForSchoolReserveMealTime)
	if err != nil {
		return
	}

	//1、查询出套餐基础设置
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(buyPackageReq.EnterpriseId)
	centralKitchenForSchoolWithSpecData, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		return
	}
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	classWithUserInfo, err := classWithUserDb.GetInfoByUserIdentityId(buyPackageReq.UserIdentityId)
	if err != nil {
		return
	}

	now := time.Now()
	today, _ := time.ParseInLocation("2006-01-02", time.Now().Format("2006-01-02"), time.Local)
	tomorrowDay := today.AddDate(0, 0, 1)

	centralKitchenForSchoolReserveMealTime, _ := time.ParseInLocation("2006-01-02 15:04:05", now.Format("2006-01-02")+" "+cfg.Val+":00", time.Local)

	//2、循环拼接数据
	for _, v1 := range buyPackageReq.WithDays {
		//2.1、判断是否小于今天
		date, _ := time.ParseInLocation("2006-01-02", v1.Date, time.Local)
		if today.After(date) || today.Equal(date) {
			continue
		}
		if tomorrowDay.Equal(date) {
			//2.2、判断是否过了今日可订餐时间
			if now.After(centralKitchenForSchoolReserveMealTime) {
				continue
			}
		}

		//2.3、计算价格 && 组装数据
		if v1.IsBuyBreakfast == 1 && buyPackageReq.IsBuyBreakfast == 1 {
			//早餐
			var amount string
			if isTeacher {
				amount = centralKitchenForSchoolWithSpecData.BreakfastUnitPriceForTeacher
			} else {
				amount = classWithUserInfo.Period.BreakfastUnitPrice
			}

			data = append(data, &model.CentralKitchenForSchoolUserWithDay{
				Uid:          uid,
				EnterpriseId: buyPackageReq.EnterpriseId,
				IdentityId:   buyPackageReq.UserIdentityId,
				Kind:         enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
				Date:         v1.Date,
				Amount:       amount,
				State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
			})
			totalPrice += utils.StrToFloat64(amount)
		}

		if v1.IsBuyLunch == 1 && buyPackageReq.IsBuyLunch == 1 {
			var amount string
			if isTeacher {
				amount = centralKitchenForSchoolWithSpecData.LunchUnitPriceForTeacher
			} else {
				amount = classWithUserInfo.Period.LunchUnitPrice
			}
			totalPrice += utils.StrToFloat64(amount)
			data = append(data, &model.CentralKitchenForSchoolUserWithDay{
				Uid:          uid,
				EnterpriseId: buyPackageReq.EnterpriseId,
				IdentityId:   buyPackageReq.UserIdentityId,
				Kind:         enum.CentralKitchenForSchoolUserWithDayKindForLunch,
				Date:         v1.Date,
				State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
				Amount:       amount,
			})
		}

		if v1.IsBuyDinner == 1 && buyPackageReq.IsBuyDinner == 1 {
			var amount string
			if isTeacher {
				amount = centralKitchenForSchoolWithSpecData.DinnerUnitPriceForTeacher
			} else {
				amount = classWithUserInfo.Period.DinnerUnitPrice
			}
			totalPrice += utils.StrToFloat64(amount)
			data = append(data, &model.CentralKitchenForSchoolUserWithDay{
				Uid:          uid,
				EnterpriseId: buyPackageReq.EnterpriseId,
				IdentityId:   buyPackageReq.UserIdentityId,
				Kind:         enum.CentralKitchenForSchoolUserWithDayKindForDinner,
				Amount:       amount,
				Date:         v1.Date,
				State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
			})
		}
	}

	return
}

func CalcSupplementaryByDay(uid int, isTeacher bool, buyPackageReq md2.BuyPackageReq) (totalPrice float64, data []*model.CentralKitchenForSchoolUserWithDay, err error) {
	//sysCfgDb := db.SysCfgDb{}
	//sysCfgDb.Set()
	//cfg, err := sysCfgDb.SysCfgGetOne(enum.CentralKitchenForSchoolReserveMealTime)
	//if err != nil {
	//	return
	//}

	//1、查询出套餐基础设置
	centralKitchenForSchoolWithSpec := db.CentralKitchenForSchoolWithSpec{}
	centralKitchenForSchoolWithSpec.Set(buyPackageReq.EnterpriseId)
	centralKitchenForSchoolWithSpecData, err := centralKitchenForSchoolWithSpec.GetCentralKitchenForSchoolWithSpec()
	if err != nil {
		return
	}
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	classWithUserInfo, err := classWithUserDb.GetInfoByUserIdentityId(buyPackageReq.UserIdentityId)
	if err != nil {
		return
	}

	//now := time.Now()
	//today, _ := time.ParseInLocation("2006-01-02", time.Now().Format("2006-01-02"), time.Local)
	//tomorrowDay := today.AddDate(0, 0, 1)

	//centralKitchenForSchoolReserveMealTime, _ := time.ParseInLocation("2006-01-02 15:04:05", now.Format("2006-01-02")+" "+cfg.Val+":00", time.Local)

	//2、循环拼接数据
	for _, v1 := range buyPackageReq.WithDays {
		//2.1、判断是否小于今天
		//date, _ := time.ParseInLocation("2006-01-02", v1.Date, time.Local)
		//if today.After(date) || today.Equal(date) {
		//	continue
		//}
		//if tomorrowDay.Equal(date) {
		//	//2.2、判断是否过了今日可订餐时间
		//	if now.After(centralKitchenForSchoolReserveMealTime) {
		//		continue
		//	}
		//}

		//2.3、计算价格 && 组装数据
		if v1.IsBuyBreakfast == 1 && buyPackageReq.IsBuyBreakfast == 1 {
			//早餐
			var amount string
			if isTeacher {
				amount = centralKitchenForSchoolWithSpecData.BreakfastUnitPriceForTeacher
			} else {
				amount = classWithUserInfo.Period.BreakfastUnitPrice
			}

			data = append(data, &model.CentralKitchenForSchoolUserWithDay{
				Uid:          uid,
				EnterpriseId: buyPackageReq.EnterpriseId,
				IdentityId:   buyPackageReq.UserIdentityId,
				Kind:         enum.CentralKitchenForSchoolUserWithDayKindForBreakfast,
				Date:         v1.Date,
				Amount:       amount,
				State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
			})
			totalPrice += utils.StrToFloat64(amount)
		}

		if v1.IsBuyLunch == 1 && buyPackageReq.IsBuyLunch == 1 {
			var amount string
			if isTeacher {
				amount = centralKitchenForSchoolWithSpecData.LunchUnitPriceForTeacher
			} else {
				amount = classWithUserInfo.Period.LunchUnitPrice
			}
			totalPrice += utils.StrToFloat64(amount)
			data = append(data, &model.CentralKitchenForSchoolUserWithDay{
				Uid:          uid,
				EnterpriseId: buyPackageReq.EnterpriseId,
				IdentityId:   buyPackageReq.UserIdentityId,
				Kind:         enum.CentralKitchenForSchoolUserWithDayKindForLunch,
				Date:         v1.Date,
				State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
				Amount:       amount,
			})
		}

		if v1.IsBuyDinner == 1 && buyPackageReq.IsBuyDinner == 1 {
			var amount string
			if isTeacher {
				amount = centralKitchenForSchoolWithSpecData.DinnerUnitPriceForTeacher
			} else {
				amount = classWithUserInfo.Period.DinnerUnitPrice
			}
			totalPrice += utils.StrToFloat64(amount)
			data = append(data, &model.CentralKitchenForSchoolUserWithDay{
				Uid:          uid,
				EnterpriseId: buyPackageReq.EnterpriseId,
				IdentityId:   buyPackageReq.UserIdentityId,
				Kind:         enum.CentralKitchenForSchoolUserWithDayKindForDinner,
				Amount:       amount,
				Date:         v1.Date,
				State:        enum.CentralKitchenForSchoolUserWithDayStateForWait,
			})
		}
	}

	return
}
